==> mono-2.10.2.tar.bz2: mono-2.10.2/mcs/class/System/System/UriComponents.cs <==
//
// System.UriComponents enumeration
//
// Author:
//	Sebastien Pouliot  <sebastien@ximian.com>
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

namespace System {

	[Flags]
#if NET_2_0
	public
#endif
	enum UriComponents {

		Scheme = 1,
		UserInfo = 2,
		Host = 4,
		Port = 8,
		Path = 16,
		Query = 32,
		Fragment = 64,
		StrongPort = 128,
		KeepDelimiter = 0x40000000,

		HostAndPort = Host | StrongPort,
		StrongAuthority = Host | UserInfo | StrongPort,
		AbsoluteUri = Scheme | UserInfo | Host | Port | Path | Query | Fragment,
		PathAndQuery = Path | Query,
		HttpRequestUrl = Scheme | Port| Host | Path | Query,
		SchemeAndServer = Scheme | Host | Port,
		SerializationInfoString = Int32.MinValue
	}
}

==> mono-4.2.2.10.tar.bz2: mono-4.2.2/mcs/class/System/System/UriComponents.cs <==
//
// System.UriComponents enumeration
//
// Author:
//	Sebastien Pouliot  <sebastien@ximian.com>
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

namespace System {

	[Flags]
	public enum UriComponents {

		Scheme = 1,
		UserInfo = 2,
		Host = 4,
		Port = 8,
		Path = 16,
		Query = 32,
		Fragment = 64,
		StrongPort = 128,
		NormalizedHost = 256,
		KeepDelimiter = 0x40000000,

		HostAndPort = Host | StrongPort,
		StrongAuthority = Host | UserInfo | StrongPort,
		AbsoluteUri = Scheme | UserInfo | Host | Port | Path | Query | Fragment,
		PathAndQuery = Path | Query,
		HttpRequestUrl = Scheme | Port| Host | Path | Query,
		SchemeAndServer = Scheme | Host | Port,
		SerializationInfoString = Int32.MinValue
	}
}
